==> libcamera-docs-0.1.0-1-armv7h.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/functions_10.js <==
var searchData=
[
  ['pads_0',['pads',['../classlibcamera_1_1MediaEntity.html#adb91c47fdbd1b581da492d6257bb648e',1,'libcamera::MediaEntity']]],
  ['parent_1',['parent',['../classlibcamera_1_1Object.html#a469143548519e7ac9525e5b2b45e983f',1,'libcamera::Object']]],
  ['parse_2',['parse',['../classlibcamera_1_1YamlParser.html#a13eb201394ae1cb921aab00fe9ba3e86',1,'libcamera::YamlParser']]],
  ['path_3',['path',['../classlibcamera_1_1IPAModule.html#ac4442f2b5ae1e04e0ea0341848707670',1,'libcamera::IPAModule']]],
  ['payload_4',['payload',['../classlibcamera_1_1IPCMessage.html#a18d9502a924db483ee1deffe37de8117',1,'libcamera::IPCMessage']]],
  ['pipe_5',['pipe',['../classlibcamera_1_1Camera_1_1Private.html#a765fac25ebdff5caf7be65a181cba38c',1,'libcamera::Camera::Private']]],
  ['pipelinehandler_6',['PipelineHandler',['../classlibcamera_1_1PipelineHandler.html#a3cea76fe8af047ed648bee391be7d268',1,'libcamera::PipelineHandler']]],
  ['pipelinehandlerfactory_7',['PipelineHandlerFactory',['../classlibcamera_1_1PipelineHandlerFactory.html#a9fff66424a8fe954bde1b7d07562f3ae',1,'libcamera::PipelineHandlerFactory']]],
  ['pipelinehandlerfactorybase_8',['PipelineHandlerFactoryBase',['../classlibcamera_1_1PipelineHandlerFactoryBase.html#abe0669e72e50130227b2348f4c1a7b63',1,'libcamera::PipelineHandlerFactoryBase']]],
  ['pixelformat_9',['PixelFormat',['../classlibcamera_1_1PixelFormat.html#a43fb76ceab1968a7e5f30a1850187d71',1,'libcamera::PixelFormat::PixelFormat()'],['../classlibcamera_1_1PixelFormat.html#a2c2f0ca78585a130d293aac230e82ca2',1,'libcamera::PixelFormat::PixelFormat(uint32_t fourcc, uint64_t modifier=0)']]],
  ['pixelformats_10',['pixelformats',['../classlibcamera_1_1StreamFormats.html#ab956a73dcc86314d903227ad736a29a4',1,'libcamera::StreamFormats']]],
  ['planes_11',['planes',['../structlibcamera_1_1FrameMetadata.html#a75f505da19a6f81cccbd563c6c90d595',1,'libcamera::FrameMetadata::planes()'],['../classlibcamera_1_1MappedBuffer.html#a150cdc7c892734781066e477c538a736',1,'libcamera::MappedBuffer::planes()'],['../classlibcamera_1_1FrameBuffer.html#ae498b3d8bb272526c4a8798f3e04b566',1,'libcamera::FrameBuffer::planes()'],['../structlibcamera_1_1FrameMetadata.html#ad3250df0268a98a8c08d0f7bafe318b8',1,'libcamera::FrameMetadata::planes()']]],
  ['planesize_12',['planeSize',['../classlibcamera_1_1PixelFormatInfo.html#ac7e125f99540866dac124ca50303f4f0',1,'libcamera::PixelFormatInfo::planeSize(const Size &amp;size, unsigned int plane, unsigned int align=1) const'],['../classlibcamera_1_1PixelFormatInfo.html#acce305a0a0536f2b2dfdaa99375fa7d1',1,'libcamera::PixelFormatInfo::planeSize(unsigned int height, unsigned int plane, unsigned int stride) const']]],
  ['point_13',['Point',['../classlibcamera_1_1Point.html#a5509aa185caea93bcf6e0a68d10acb18',1,'libcamera::Point::Point()'],['../classlibcamera_1_1Point.html#aa45e2057e0b3f66db6de02b63dd26556',1,'libcamera::Point::Point(int xpos, int ypos)']]],
  ['populate_14',['populate',['../classlibcamera_1_1MediaDevice.html#a8fe692b0d3675cff3e162305db246c25',1,'libcamera::MediaDevice']]],
  ['pos_15',['pos',['../classlibcamera_1_1File.html#ae941e89884152a9c7d8da39f580220ac',1,'libcamera::File']]],
  ['postmessage_16',['postMessage',['../classlibcamera_1_1Object.html#af9ae92dfe5f3741c64ebdec61a2f5bef',1,'libcamera::Object']]],
  ['prefix_17',['prefix',['../classlibcamera_1_1LogMessage.html#a8bdc2036cd01131cf77d8e3bec93acf7',1,'libcamera::LogMessage']]],
  ['prepare_18',['prepare',['../classlibcamera_1_1Request_1_1Private.html#a20f854e13dc52ec479ebc7f1a2fdc503',1,'libcamera::Request::Private::prepare()'],['../classlibcamera_1_1ipa_1_1Algorithm.html#a23ef2ba1168aca42bf1c993956d92bad',1,'libcamera::ipa::Algorithm::prepare()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1ToneMapping.html#a9ee116ad1dd98f80634335229a5ef6d3',1,'libcamera::ipa::ipu3::algorithms::ToneMapping::prepare()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Awb.html#a525add4516a50bb8e9d82f4ab10da17e',1,'libcamera::ipa::ipu3::algorithms::Awb::prepare()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Af.html#a50edbc40bd8238f2d37e826494142dcf',1,'libcamera::ipa::ipu3::algorithms::Af::prepare()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1BlackLevelCorrection.html#a101a245dfb4a86be717f9f6f6df447f5',1,'libcamera::ipa::ipu3::algorithms::BlackLevelCorrection::prepare()']]],
  ['private_19',['Private',['../classlibcamera_1_1Extensible_1_1Private.html#a58af2c3e5a3ff3301df0a10ea282c766',1,'libcamera::Extensible::Private::Private()'],['../classlibcamera_1_1Camera_1_1Private.html#a9a4e997ad0fab497b95350f7bc82ec16',1,'libcamera::Camera::Private::Private()'],['../classlibcamera_1_1FrameBuffer_1_1Private.html#a9ea38d3356e65c53088717cfeaa11dbf',1,'libcamera::FrameBuffer::Private::Private()'],['../classlibcamera_1_1Request_1_1Private.html#a6d334bff3c7a4d007c94a5f08310e0a5',1,'libcamera::Request::Private::Private()']]],
  ['process_20',['process',['../classlibcamera_1_1ipa_1_1Algorithm.html#a7d9ab59a559a746398e7dc3f32cfa716',1,'libcamera::ipa::Algorithm::process()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1ToneMapping.html#a7ec1e1264e29c61864ce4e1c85b8b4d4',1,'libcamera::ipa::ipu3::algorithms::ToneMapping::process()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Awb.html#a85b4f58b1c62a7aeaf5f073698679a39',1,'libcamera::ipa::ipu3::algorithms::Awb::process()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Agc.html#a2559951592bcfd9792bda394a8d4e79b',1,'libcamera::ipa::ipu3::algorithms::Agc::process()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Af.html#a31e1bf756c1ac08786db1ca5a7c136b7',1,'libcamera::ipa::ipu3::algorithms::Af::process()']]],
  ['processevents_21',['processEvents',['../classlibcamera_1_1EventDispatcher.html#a33dea42b992409416799a48dc32fec90',1,'libcamera::EventDispatcher::processEvents()'],['../classlibcamera_1_1EventDispatcherPoll.html#aeecb48a1f8a12fa36a6764299baebba8',1,'libcamera::EventDispatcherPoll::processEvents()']]],
  ['processmanager_22',['ProcessManager',['../classlibcamera_1_1ProcessManager.html#aab5a24aa2f56eebb013e94a5b0b74b18',1,'libcamera::ProcessManager']]],
  ['processstatsbuffer_23',['processStatsBuffer',['../classlibcamera_1_1ipa_1_1ipu3_1_1IPAIPU3.html#a7f99735859cf00704f400796b5a6c432',1,'libcamera::ipa::ipu3::IPAIPU3']]],
  ['properties_24',['properties',['../classlibcamera_1_1Camera.html#a99c4d8a70c8821e7d36bc04c3c34c217',1,'libcamera::Camera::properties()'],['../classlibcamera_1_1CameraSensor.html#a0034fd3d15f8c59ab0ccc17e2ae84e8a',1,'libcamera::CameraSensor::properties()']]],
  ['pubkey_25',['PubKey',['../classlibcamera_1_1PubKey.html#a1f466a8d905b96bf1860226316ce0bcd',1,'libcamera::PubKey']]],
  ['pubkey_26',['pubKey',['../classlibcamera_1_1IPAManager.html#a26b6a8a96ca4881fd54d8396b58b4da5',1,'libcamera::IPAManager']]],
  ['push_27',['push',['../classlibcamera_1_1DelayedControls.html#a6e4ac7f9c74b6f62d4c47f0e455ba84c',1,'libcamera::DelayedControls']]],
  ['put_28',['put',['../classlibcamera_1_1V4L2BufferCache.html#a561f0eee632e4a465f1813abe29abdea',1,'libcamera::V4L2BufferCache']]]
];

==> libcamera-docs-0.1.0-2-armv7h.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/functions_10.js <==
var searchData=
[
  ['pads_0',['pads',['../classlibcamera_1_1MediaEntity.html#adb91c47fdbd1b581da492d6257bb648e',1,'libcamera::MediaEntity']]],
  ['parent_1',['parent',['../classlibcamera_1_1Object.html#a469143548519e7ac9525e5b2b45e983f',1,'libcamera::Object']]],
  ['parse_2',['parse',['../classlibcamera_1_1YamlParser.html#a13eb201394ae1cb921aab00fe9ba3e86',1,'libcamera::YamlParser']]],
  ['path_3',['path',['../classlibcamera_1_1IPAModule.html#ac4442f2b5ae1e04e0ea0341848707670',1,'libcamera::IPAModule']]],
  ['payload_4',['payload',['../classlibcamera_1_1IPCMessage.html#a18d9502a924db483ee1deffe37de8117',1,'libcamera::IPCMessage']]],
  ['pipe_5',['pipe',['../classlibcamera_1_1Camera_1_1Private.html#a765fac25ebdff5caf7be65a181cba38c',1,'libcamera::Camera::Private']]],
  ['pipelinehandler_6',['PipelineHandler',['../classlibcamera_1_1PipelineHandler.html#a3cea76fe8af047ed648bee391be7d268',1,'libcamera::PipelineHandler']]],
  ['pipelinehandlerfactory_7',['PipelineHandlerFactory',['../classlibcamera_1_1PipelineHandlerFactory.html#a9fff66424a8fe954bde1b7d07562f3ae',1,'libcamera::PipelineHandlerFactory']]],
  ['pipelinehandlerfactorybase_8',['PipelineHandlerFactoryBase',['../classlibcamera_1_1PipelineHandlerFactoryBase.html#abe0669e72e50130227b2348f4c1a7b63',1,'libcamera::PipelineHandlerFactoryBase']]],
  ['pixelformat_9',['pixelformat',['../classlibcamera_1_1PixelFormat.html#a43fb76ceab1968a7e5f30a1850187d71',1,'libcamera::PixelFormat::PixelFormat()'],['../classlibcamera_1_1PixelFormat.html#a2c2f0ca78585a130d293aac230e82ca2',1,'libcamera::PixelFormat::PixelFormat(uint32_t fourcc, uint64_t modifier=0)']]],
  ['pixelformats_10',['pixelformats',['../classlibcamera_1_1StreamFormats.html#ab956a73dcc86314d903227ad736a29a4',1,'libcamera::StreamFormats']]],
  ['planes_11',['planes',['../structlibcamera_1_1FrameMetadata.html#a75f505da19a6f81cccbd563c6c90d595',1,'libcamera::FrameMetadata::planes()'],['../classlibcamera_1_1MappedBuffer.html#a150cdc7c892734781066e477c538a736',1,'libcamera::MappedBuffer::planes()'],['../classlibcamera_1_1FrameBuffer.html#ae498b3d8bb272526c4a8798f3e04b566',1,'libcamera::FrameBuffer::planes()'],['../structlibcamera_1_1FrameMetadata.html#ad3250df0268a98a8c08d0f7bafe318b8',1,'libcamera::FrameMetadata::planes()']]],
  ['planesize_12',['planesize',['../classlibcamera_1_1PixelFormatInfo.html#ac7e125f99540866dac124ca50303f4f0',1,'libcamera::PixelFormatInfo::planeSize(const Size &amp;size, unsigned int plane, unsigned int align=1) const'],['../classlibcamera_1_1PixelFormatInfo.html#acce305a0a0536f2b2dfdaa99375fa7d1',1,'libcamera::PixelFormatInfo::planeSize(unsigned int height, unsigned int plane, unsigned int stride) const']]],
  ['point_13',['point',['../classlibcamera_1_1Point.html#a5509aa185caea93bcf6e0a68d10acb18',1,'libcamera::Point::Point()'],['../classlibcamera_1_1Point.html#aa45e2057e0b3f66db6de02b63dd26556',1,'libcamera::Point::Point(int xpos, int ypos)']]],
  ['populate_14',['populate',['../classlibcamera_1_1MediaDevice.html#a8fe692b0d3675cff3e162305db246c25',1,'libcamera::MediaDevice']]],
  ['pos_15',['pos',['../classlibcamera_1_1File.html#ae941e89884152a9c7d8da39f580220ac',1,'libcamera::File']]],
  ['postmessage_16',['postMessage',['../classlibcamera_1_1Object.html#af9ae92dfe5f3741c64ebdec61a2f5bef',1,'libcamera::Object']]],
  ['prefix_17',['prefix',['../classlibcamera_1_1LogMessage.html#a8bdc2036cd01131cf77d8e3bec93acf7',1,'libcamera::LogMessage']]],
  ['prepare_18',['prepare',['../classlibcamera_1_1Request_1_1Private.html#a20f854e13dc52ec479ebc7f1a2fdc503',1,'libcamera::Request::Private::prepare()'],['../classlibcamera_1_1ipa_1_1Algorithm.html#a23ef2ba1168aca42bf1c993956d92bad',1,'libcamera::ipa::Algorithm::prepare()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1ToneMapping.html#a9ee116ad1dd98f80634335229a5ef6d3',1,'libcamera::ipa::ipu3::algorithms::ToneMapping::prepare()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Awb.html#a525add4516a50bb8e9d82f4ab10da17e',1,'libcamera::ipa::ipu3::algorithms::Awb::prepare()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Af.html#a50edbc40bd8238f2d37e826494142dcf',1,'libcamera::ipa::ipu3::algorithms::Af::prepare()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1BlackLevelCorrection.html#a101a245dfb4a86be717f9f6f6df447f5',1,'libcamera::ipa::ipu3::algorithms::BlackLevelCorrection::prepare()']]],
  ['private_19',['private',['../classlibcamera_1_1Extensible_1_1Private.html#a58af2c3e5a3ff3301df0a10ea282c766',1,'libcamera::Extensible::Private::Private()'],['../classlibcamera_1_1Camera_1_1Private.html#a9a4e997ad0fab497b95350f7bc82ec16',1,'libcamera::Camera::Private::Private()'],['../classlibcamera_1_1FrameBuffer_1_1Private.html#a9ea38d3356e65c53088717cfeaa11dbf',1,'libcamera::FrameBuffer::Private::Private()'],['../classlibcamera_1_1Request_1_1Private.html#a6d334bff3c7a4d007c94a5f08310e0a5',1,'libcamera::Request::Private::Private()']]],
  ['process_20',['process',['../classlibcamera_1_1ipa_1_1Algorithm.html#a7d9ab59a559a746398e7dc3f32cfa716',1,'libcamera::ipa::Algorithm::process()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1ToneMapping.html#a7ec1e1264e29c61864ce4e1c85b8b4d4',1,'libcamera::ipa::ipu3::algorithms::ToneMapping::process()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Awb.html#a85b4f58b1c62a7aeaf5f073698679a39',1,'libcamera::ipa::ipu3::algorithms::Awb::process()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Agc.html#a2559951592bcfd9792bda394a8d4e79b',1,'libcamera::ipa::ipu3::algorithms::Agc::process()'],['../classlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Af.html#a31e1bf756c1ac08786db1ca5a7c136b7',1,'libcamera::ipa::ipu3::algorithms::Af::process()']]],
  ['processevents_21',['processevents',['../classlibcamera_1_1EventDispatcher.html#a33dea42b992409416799a48dc32fec90',1,'libcamera::EventDispatcher::processEvents()'],['../classlibcamera_1_1EventDispatcherPoll.html#aeecb48a1f8a12fa36a6764299baebba8',1,'libcamera::EventDispatcherPoll::processEvents()']]],
  ['processmanager_22',['ProcessManager',['../classlibcamera_1_1ProcessManager.html#aab5a24aa2f56eebb013e94a5b0b74b18',1,'libcamera::ProcessManager']]],
  ['processstatsbuffer_23',['processStatsBuffer',['../classlibcamera_1_1ipa_1_1ipu3_1_1IPAIPU3.html#a7f99735859cf00704f400796b5a6c432',1,'libcamera::ipa::ipu3::IPAIPU3']]],
  ['properties_24',['properties',['../classlibcamera_1_1Camera.html#a99c4d8a70c8821e7d36bc04c3c34c217',1,'libcamera::Camera::properties()'],['../classlibcamera_1_1CameraSensor.html#a0034fd3d15f8c59ab0ccc17e2ae84e8a',1,'libcamera::CameraSensor::properties()']]],
  ['pubkey_25',['pubkey',['../classlibcamera_1_1PubKey.html#a1f466a8d905b96bf1860226316ce0bcd',1,'libcamera::PubKey::PubKey()'],['../classlibcamera_1_1IPAManager.html#a26b6a8a96ca4881fd54d8396b58b4da5',1,'libcamera::IPAManager::pubKey()']]],
  ['push_26',['push',['../classlibcamera_1_1DelayedControls.html#a6e4ac7f9c74b6f62d4c47f0e455ba84c',1,'libcamera::DelayedControls']]],
  ['put_27',['put',['../classlibcamera_1_1V4L2BufferCache.html#a561f0eee632e4a465f1813abe29abdea',1,'libcamera::V4L2BufferCache']]]
];
